summaryrefslogtreecommitdiffstats
path: root/example/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'example/main.cpp')
-rw-r--r--example/main.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/example/main.cpp b/example/main.cpp
index 3c2722c..a24a49f 100644
--- a/example/main.cpp
+++ b/example/main.cpp
@@ -3,19 +3,19 @@
**
** Copyright (C) 1992-2000 Trolltech AS. All rights reserved.
**
** This file is part of an example program for Qt. This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/
-#include <qapplication.h>
+#include <tqapplication.h>
#include "application.h"
int main( int argc, char ** argv ) {
- QApplication a( argc, argv );
+ TQApplication a( argc, argv );
ApplicationWindow *mw = new ApplicationWindow();
- mw->setCaption( "QScintilla Example - Application" );
+ mw->setCaption( "TQScintilla Example - Application" );
mw->show();
- a.connect( &a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()) );
+ a.connect( &a, TQT_SIGNAL(lastWindowClosed()), &a, TQT_SLOT(quit()) );
return a.exec();
}
@@ -3,19 +3,19 @@
** Copyright (C) 1992-2000 Trolltech AS. All rights reserved.
**
-** This file is part of an example program for Qt. This example
+** This file is part of an example program for TQt. This example
** program may be used, distributed and modified without limitation.
**